@@ -65,29 +65,27 @@ class table_objects:
     def count(self):
         return len(self.obj.columns)
     
-    def filter(self, data=None):
-        '''Future Method:
-        :need = len(kwargs)
-        :result = []
-        :for column in self.obj.columns:
-        :    transit = 0
-        :    for kwarg in kwargs:
-        :        if kwargs[kwarg] in column.data:
-        :            transit += 1
-        :    if transit == need:
-        :        result.append(column)
-        ;return result
-        '''
+    def filter(self, *args, **kwargs):
+        need = len(kwargs)
+        result = []
         for column in self.obj.columns:
-            if data == column.data:
-                return column
+            transit = 0
+            for kwarg in kwargs:
+                if kwargs[kwarg] in column.data:
+                    transit += 1
+            if transit == need:
+                result.append(column)
+        return result
+        #for column in self.obj.columns:
+        #    if data == column.data:
+        #        return column
 
 class SqleeData:
     data = None
     url = None
     repo = None
     id = None
-    def __init__(self, data, url=None, repo=None):
+    def __init__(self, data, url=None, repo=None, namespace=[]):
         if not isinstance(url, str) and not isinstance(url, URL):
             raise ValueError("参数'url'必须是字符串.")
         if not isinstance(repo, GiteeRepo):
@@ -95,6 +93,7 @@ class SqleeData:
         self.data = data
         self.url = url
         self.repo = repo
+        self.namespace = namespace
 
     @property
     def type(self):
@@ -116,13 +115,16 @@ class SqleeData:
         del self
         return answer
 
+    def __str__(self):
+        return self.data
+
 class SqleeColumn:
     datas = []
-    url = None
     repo = None
     table = None
     id = None
-    def __init__(self, url=None, repo=None, id=None, *args, **kwargs):
+    def __init__(self, url=None, repo=None, id=None, table=None,
+                 namespace=[], *args, **kwargs):
         if not isinstance(url, str) and not isinstance(url, URL):
             raise ValueError("参数'url'必须是字符串或URL.")
         if not isinstance(id, int):
@@ -132,8 +134,9 @@ class SqleeColumn:
 
         self.id = id
         self.repo = repo
+        self.table = table
         self.url = url
-        self.table = str(self.url).split("/")[-3]
+        self.namespace = namespace
         self.sync()
 
     @property
@@ -152,12 +155,30 @@ class SqleeColumn:
 
     def sync(self):
         self.datas = []
-        datas = self.repo.list_file(path="%s/%d" % (self.table, self.id), detail=True)
+        datas = [self.id, ]
+        datas += list(self.repo.list_file(path="%s/%d" % (self.table.name, self.id), detail=True))
         for data in datas:
-            if data["name"] != ".keep":
+            if isinstance(data, int):
+                continue
+            if data["name"] == ".keep":
+                del datas[datas.index(data)]
+        for data in datas:
+            if isinstance(data, int):
                 self.datas.append(
-                    SqleeData(self.repo.get_data(path="%s/%d/%s" % (self.table, self.id, data["name"])), url=data["url"], repo=self.repo)
+                    SqleeData(data, url="id",
+                              namespace="id",
+                              repo=self.repo)
                     )
+                continue
+            loads = self.repo.get_data(path=data["path"])
+            exec("self.%s = %s" % (self.namespace[int(data["name"])], loads))
+            self.datas.append(
+                SqleeData(loads, url=data["url"],
+                          namespace=self.namespace[int(data["name"])],
+                          repo=self.repo)
+                )
+        if len(datas) != len(self.namespace):
+            raise ValueError("数据错误: 数据与命名域不符合.")
         self.datas = tuple(self.datas)
         return self.datas
         
@@ -175,8 +196,6 @@ class SqleeColumn:
 
 class SqleeTable:
     columns = []
-    name = None
-    namespace = []
     def __init__(self, name=None, repo=None):
         if not isinstance(name, str) and not isinstance(name, URL):
             raise ValueError("参数'name'必须是字符串或URL.")
@@ -200,14 +219,17 @@ class SqleeTable:
         return self.objects.create(datas=datas)
 
     def sync(self):
-        self.namespace = self.repo.get_file(path=URL(self.name)/".namespace")
+        self.namespace = ["id", ]
+        self.namespace += json.loads(self.repo.get_file(path=URL(self.name)/".namespace"))
         self.columns = []
         for column in self.repo.list_folder_int(path=self.name):
             self.columns.append(
                 SqleeColumn(
                     url = self.url / column,
                     repo = self.repo,
-                    id = int(column)
+                    id = int(column),
+                    table = self,
+                    namespace = self.namespace,
                     )
                 )
         self.columns = tuple(self.columns)
